"""
Pydantic Models for MONITOR - system/firmware/upgrade

Runtime validation models for system/firmware/upgrade configuration.
Generated from FortiOS schema version unknown.
"""

from __future__ import annotations

from pydantic import BaseModel, Field
from typing import Any, Optional
from enum import Enum

# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================

class UpgradeSourceEnum(str, Enum):
    """Allowed values for source field."""
    UPLOAD = "upload"
    USB = "usb"
    FORTIGUARD = "fortiguard"
    URL = "url"


# ============================================================================
# Main Model
# ============================================================================

class UpgradeModel(BaseModel):
    """
    Pydantic model for system/firmware/upgrade configuration.
    
    Upgrade firmware image on this device.
    
    Validation Rules:        - source: pattern=        - url: pattern=        - passphrase: pattern=        - force: pattern=        - filename: pattern=        - format_partition: pattern=        - ignore_invalid_signature: pattern=        - file_id: pattern=        - ignore_admin_lockout_upon_downgrade: pattern=        - file_content: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    source: UpgradeSourceEnum = Field()    
    url: str | None = Field(default=None)    
    passphrase: str | None = Field(default=None)    
    force: Any = Field(default=None)    
    filename: str | None = Field(default=None)    
    format_partition: Any = Field(default=None)    
    ignore_invalid_signature: Any = Field(default=None)    
    file_id: str | None = Field(default=None)    
    ignore_admin_lockout_upon_downgrade: Any = Field(default=None)    
    file_content: str | None = Field(default=None)    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "UpgradeModel":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "UpgradeModel",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.0
# Generated: 2026-01-21T16:24:03.695706Z
# ============================================================================