"""
Auto-generated normalization field sets from schema analysis.

Generated by: .dev/scripts/analyze_normalizable_fields.py
"""

# Simple array fields that use plain list format (not [{'name': '...'}])
# These should use normalize_to_string_list()
SIMPLE_ARRAY_FIELDS = {
    "admins",
    "commands",
    "config_ids",
    "devs",
    "dstintfrole",
    "endpoint_ip",
    "filters",
    "fortiextender-name",
    "fqdn",
    "guest",
    "hosts",
    "id_list",
    "ip",
    "ip_addresses",
    "macs",
    "mgmt_url_parameters",
    "mkeys",
    "objects",
    "orgunits",
    "policyid",
    "port_ranges",
    "ports",
    "qtypes",
    "report_types",
    "search_tables",
    "serials",
    "skip_tables",
    "srcintfrole",
    "tokens",
    "url",
    "user_group",
    "users",
    "uuid",
    "uuids",
}

# Table/complex fields with 'name' child that use [{'name': '...'}, ...] format
# These should use normalize_to_name_list()
NAME_LIST_FIELDS = {
}

# Multi-value option fields (space-separated strings)
# These should use normalize_day_field() or similar
MULTI_VALUE_OPTION_FIELDS = {
}
