"""FortiOS Service - Service subcategory"""

# This is an auto-placeholder for the service/service category


class Service:
    """Service sub-endpoints wrapper."""

    def __init__(self, client):
        """Initialize service sub-category.
        
        Args:
            client: HTTP client instance for API communication
        """
        # No endpoints directly under this category
        pass


__all__ = ["Service"]
