"""FortiOS Monitor - Monitor subcategory"""

# This is an auto-placeholder for the monitor/monitor category


class Monitor:
    """Monitor sub-endpoints wrapper."""

    def __init__(self, client):
        """Initialize monitor sub-category.
        
        Args:
            client: HTTP client instance for API communication
        """
        # No endpoints directly under this category
        pass


__all__ = ["Monitor"]
